@@ -1,5 +1,5 @@
 __doc__ = '''Calendar tag'''
-__version__='1.0.12'
+__version__='1.0.13'
 
 
 from string import capitalize, join, replace, split
@@ -28,14 +28,19 @@ except ImportError:
 
 start = """
 <table border="0" bgcolor="%(bgcolor)s" cellspacing="0" cellpadding="0"%(tablewidth)s>
- <tr><td><table border=0 cellspacing=0 cellpadding=0>
  <tr>
-  <td align="center" valign="middle" bgcolor="%(leftbgcolor)s">
-   <font color="%(leftfgcolor)s"style="font-family:verdana,sans-serif;font-size:12 px;"><b>%(left)s</b></font></td>
-  %(middle)s
-  %(right)s
+    <td><table border="0" cellspacing="0" cellpadding="0">
+      <tr>
+          <td align="center" valign="middle" bgcolor="%(leftbgcolor)s">
+              <font color="%(leftfgcolor)s"style="font-family:verdana,sans-serif;font-size:12 px;"><b>%(left)s</b></font>
+          </td>
+          %(middle)s
+          %(right)s
+     </tr>
+    </td>
  </tr>
- </table></td></tr>
+</table>
+<table border="0" bgcolor="%(bgcolor)s" cellspacing="0" cellpadding="0"%(tablewidth)s>
 """
 
 end = """
@@ -45,7 +50,7 @@ end = """
 body_start = """
  <tr>
   <td bgcolor="%(bordercolor)s" align="center" valign="middle" colspan="%(colspan)s">
-   <table border=0 width="100%%" cellspacing="%(spacing)s" cellpadding="%(padding)s">
+   <table border="0" width="100%%" cellspacing="%(spacing)s" cellpadding="%(padding)s">
 """
 
 body_end = """
@@ -648,7 +653,9 @@ def translate(word, lang):
 
 
 def datestr(date):
-    return '%d-%s-%s' % (date.year(), date.mm(), date.dd())
+    # note we must use yy/mm/dd instead of yy-mm-dd
+    # to preserve the date time in localtime
+    return '%d/%s/%s' % (date.year(), date.mm(), date.dd())
 
 
 def name_or_expr(mapping, name_attr, expr_attr, default):
@@ -983,10 +990,11 @@ class CalendarTag:
                 d = bd
                 month = bd.month()
                 while d.month() == month:
-                    if c == self.week_ndays:
+                    if c == 7:
                         s = s + '</tr><tr>'
                         c = 0
-                    s = s + self.render_day_(md, d, d == bd)
+                    if c < self.week_ndays:
+                        s = s + self.render_day_(md, d, d == bd)
                     d = d + 1
                     c = c + 1
                 if c < self.week_ndays:
